types.ChunkedDocumentLike
Structural type for a document that already carries its chunks.
Usage
types.ChunkedDocumentLike()Like DocumentLike, but it also exposes a chunks sequence of ChunkLike objects. ChunkedDocument.from_any() normalizes such objects into a raghilda ChunkedDocument.