types.IntoChunk
Any object that can be converted into a Chunk via to_chunk().
Usage
types.IntoChunk()Methods
| Name | Description |
|---|---|
| to_chunk() | Convert this object into a Chunk. |
to_chunk()
Convert this object into a Chunk.
Usage
to_chunk()Any object that can be converted into a Chunk via to_chunk().
Usage
| Name | Description |
|---|---|
| to_chunk() | Convert this object into a Chunk. |
Convert this object into a Chunk.
Usage